const query = `PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX dc: <http://purl.org/dc/elements/1.1/>
PREFIX dct: <http://purl.org/dc/terms/>
PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
PREFIX edm: <http://www.europeana.eu/schemas/edm/>
PREFIX foaf: <http://xmlns.com/foaf/0.1/>
PREFIX hdlh: <https://hdl.handle.net/20.500.11840/termmaster>
PREFIX wgs84: <http://www.w3.org/2003/01/geo/wgs84_pos#>
PREFIX geo: <http://www.opengis.net/ont/geosparql#>
PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
PREFIX gn: <http://www.geonames.org/ontology#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
# een foto per lat long (met type, img, lat en long van de plaats
SELECT  (SAMPLE(?cho) AS ?cho)
		?title
        # (SAMPLE(?title) AS ?title)
        (SAMPLE(?typeLabel) AS ?type)
        (SAMPLE(?img) AS ?img)
		(SAMPLE(?placeName) AS ?placeName)
        (SAMPLE(?landLabel) AS ?landLabel)
		(SAMPLE(?date) AS ?date)
		(SAMPLE(?lat) AS ?lat)
		(SAMPLE(?long) AS ?long)

WHERE {
 # vind alleen foto's
 <https://hdl.handle.net/20.500.11840/termmaster1397> skos:narrower* ?type .
 ?type skos:prefLabel ?typeLabel .
 ?cho edm:object ?type .
  
 ?cho edm:isShownBy ?img .
 ?cho dc:title ?title .
  
 # vind bij de plaats van de foto de lat/long
 ?cho dct:spatial ?place .
 ?place skos:exactMatch/wgs84:lat ?lat .
 ?place skos:exactMatch/wgs84:long ?long .
  
 # vind bij de plaats van de het land
 ?place skos:exactMatch/gn:parentCountry ?land .
 ?place skos:prefLabel ?placeName .
 ?land gn:name ?landLabel .
  
 ?cho dct:created ?date .
 BIND (xsd:gYear(?date) AS ?year) .
 FILTER (?year < xsd:gYear("2100"))
  
 FILTER langMatches(lang(?title), "ned")
  
} GROUP BY ?title`
//Please use your own endpoint when using this 
const endpoint = "https://api.data.netwerkdigitaalerfgoed.nl/datasets/ivo/NMVW/services/NMVW-40/sparql"
const  dataSource = 'https://gist.githubusercontent.com/Razpudding/f34e3dcabb5b950f468a68077cefda96/raw/a5a85adf3562e24e17a993c989f61ffcc9ecb2a1/surveyData.csv'

makeVisualization()

// Our main function which runs other function to make a visualization
async function makeVisualization(){
  //Wait for the promise to resolve with the data
  let data = await loadData(endpoint, query)
  console.log("rawData: ", data)
	data = data.map(cleanData)
  console.log("cleanedData: ", data)
	data = transformData(data)
  console.log("transformedData: ", data)
  console.log(data)
  data = jaar(data)
}

//Load the data and return a promise which resolves with said data
function loadData(url, query){
  return d3.json(endpoint +"?query="+ encodeURIComponent(query) + "&format=json")
    .then(data => data.results.bindings)
}

//Nest the data per date
function transformData(source){
  let transformed =  d3.nest()
		// .key(function(d) { return d.landLabel; })
  	.key(function(d) { return d.date; })
		.entries(source);
  transformed.forEach(country => {
    country.amount = country.values.length
  })
  return transformed
}

//This function gets the nested value out of the object in each property
// in our data
function cleanData(row){
   let result = {}
    Object.entries(row)
    	.forEach(([key, propValue]) => { 		
				result[key] = propValue.value
  	})
   return result
}

function jaar(data) {
	console.log('test')
}